Struct Header

struct Header { ... }

The header at the start of an archive member.

Fields

name: [u8; 16]

The file name.

date: [u8; 12]

File modification timestamp in decimal.

uid: [u8; 6]

User ID in decimal.

gid: [u8; 6]

Group ID in decimal.

mode: [u8; 8]

File mode in octal.

size: [u8; 10]

File size in decimal.

terminator: [u8; 2]

Must be equal to TERMINATOR.

Implementations

impl Clone for Header

fn clone(self: &Self) -> Header

impl Copy for Header

impl Debug for Header

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for Header

impl Pod for Header

impl RefUnwindSafe for Header

impl Send for Header

impl Sync for Header

impl Unpin for Header

impl UnsafeUnpin for Header

impl UnwindSafe for Header

impl<T> Any for Header

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Header

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Header

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Header

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Header

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Header

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Header

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Header

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Header

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>