Interface for building object files.
This module provides common types and traits used in the builders.
The submodules define the builders for each file format.
Modules
- elf
- This module provides a
Builderfor reading, modifying, and then writing ELF files. - macho
- This module provides a
Builderfor reading, modifying, and then writing Mach-O files.
Structs
- Byte
String - A byte slice that is a string of an unknown encoding.
- Bytes
- A byte slice.
- Error
- The error type used within the build module.
- Table
- A table of items.
Traits
Type Aliases
- Result
- The result type used within the build module.