pub enum Dynamic<'data> {
Auto {
tag: u32,
},
Integer {
tag: u32,
val: u64,
},
String {
tag: u32,
val: ByteString<'data>,
},
}Expand description
An entry in the dynamic section.
This corresponds to elf::Dyn32 or elf::Dyn64.
Variants
Auto
The value is an automatically generated integer.
Writing will fail if the value cannot be automatically generated.
Integer
The value is an integer.
Fields
String
The value is a string.
Fields

val: ByteString<'data>The string value.
This will be stored in the dynamic string section.
Implementations