Id

Trait Id 

pub trait Id: IdPrivate {
    // Required method
    fn index(&self) -> usize;
}
An identifier for referring to an item in a Table.

Required Methods

fn index(&self) -> usize

Return the index of the item in the table.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl Id for SectionId

Source

impl Id for SegmentId

Source

impl Id for VersionFileId

Source

impl Id for VersionId

Source

impl<const DYNAMIC: bool> Id for SymbolId<DYNAMIC>