Enum object::AddressSize [−][src]
#[non_exhaustive]
#[repr(u8)]
pub enum AddressSize {
U8,
U16,
U32,
U64,
}Expand description
The size of an address value for an architecture.
This may differ from the address size supported by the file format (such as for COFF).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations