Struct object::macho::DyldSubCacheInfo
source · [−]#[repr(C)]pub struct DyldSubCacheInfo<E: Endian> {
pub uuid: [u8; 16],
pub cumulative_size: U64<E>,
}Expand description
Corresponds to a struct whose source code has not been published as of Nov 2021. Added in the dyld cache version which shipped with macOS 12 / iOS 15.
Fields
uuid: [u8; 16]The UUID of this subcache.
cumulative_size: U64<E>The size of this subcache plus all previous subcaches.