pub struct SectionFlags(pub u32);Expand description
Values for Section*::flags.
Tuple Fields
0: u32Implementations
Sourceimpl SectionFlags
impl SectionFlags
Sourcepub fn typ(self) -> SectionType
pub fn typ(self) -> SectionType
Get the section type field.
Sourcepub const fn with_type(self, typ: SectionType) -> SectionFlags
pub const fn with_type(self, typ: SectionType) -> SectionFlags
Set the section type field.
Sourceimpl SectionFlags
impl SectionFlags
Sourcepub fn contains(self, other: SectionFlags) -> bool
pub fn contains(self, other: SectionFlags) -> bool
Returns true if all bits set in other are set in self.
Sourcepub fn intersects(self, other: SectionFlags) -> bool
pub fn intersects(self, other: SectionFlags) -> bool
Returns true if any bit set in other is set in self.
Sourcepub const fn with(self, other: SectionFlags) -> Self
pub const fn with(self, other: SectionFlags) -> Self
Returns self with the specified flags set.
Sourcepub const fn without(self, other: SectionFlags) -> Self
pub const fn without(self, other: SectionFlags) -> Self
Returns self with the specified flags cleared.
Sourcepub fn insert(&mut self, other: SectionFlags)
pub fn insert(&mut self, other: SectionFlags)
Set the specified flags.
Sourcepub fn remove(&mut self, other: SectionFlags)
pub fn remove(&mut self, other: SectionFlags)
Clear the specified flags.
Sourceimpl SectionFlags
impl SectionFlags
pub const NAMES: &'static FlagNames<SectionFlags>