Struct ImageDebugMisc
struct ImageDebugMisc { ... }
Fields
data_type: U32<LittleEndian>type of misc data, see defines
length: U32<LittleEndian>total length of record, rounded to four byte multiple.
unicode: u8TRUE if data is unicode string
reserved: [u8; 3]
Implementations
impl Clone for ImageDebugMisc
fn clone(self: &Self) -> ImageDebugMisc
impl Copy for ImageDebugMisc
impl Debug for ImageDebugMisc
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for ImageDebugMisc
impl Pod for ImageDebugMisc
impl RefUnwindSafe for ImageDebugMisc
impl Send for ImageDebugMisc
impl Sync for ImageDebugMisc
impl Unpin for ImageDebugMisc
impl UnsafeUnpin for ImageDebugMisc
impl UnwindSafe for ImageDebugMisc
impl<T> Any for ImageDebugMisc
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ImageDebugMisc
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ImageDebugMisc
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for ImageDebugMisc
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for ImageDebugMisc
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for ImageDebugMisc
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for ImageDebugMisc
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ImageDebugMisc
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ImageDebugMisc
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>