Struct ImageDelayloadDescriptor

struct ImageDelayloadDescriptor { ... }

Fields

attributes: U32<LittleEndian>
dll_name_rva: U32<LittleEndian>

RVA to the name of the target library (NULL-terminate ASCII string)

module_handle_rva: U32<LittleEndian>

RVA to the HMODULE caching location (PHMODULE)

import_address_table_rva: U32<LittleEndian>

RVA to the start of the IAT (PIMAGE_THUNK_DATA)

import_name_table_rva: U32<LittleEndian>

RVA to the start of the name table (PIMAGE_THUNK_DATA::AddressOfData)

bound_import_address_table_rva: U32<LittleEndian>

RVA to an optional bound IAT

unload_information_table_rva: U32<LittleEndian>

RVA to an optional unload info table

time_date_stamp: U32<LittleEndian>

0 if not bound, otherwise, date/time of the target DLL

Implementations

impl ImageDelayloadDescriptor

fn is_null(self: &Self) -> bool

Tell whether this delay-load import descriptor is the null descriptor (used to mark the end of the iterator array in a PE)

impl Clone for ImageDelayloadDescriptor

fn clone(self: &Self) -> ImageDelayloadDescriptor

impl Copy for ImageDelayloadDescriptor

impl Debug for ImageDelayloadDescriptor

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for ImageDelayloadDescriptor

impl Pod for ImageDelayloadDescriptor

impl RefUnwindSafe for ImageDelayloadDescriptor

impl Send for ImageDelayloadDescriptor

impl Sync for ImageDelayloadDescriptor

impl Unpin for ImageDelayloadDescriptor

impl UnsafeUnpin for ImageDelayloadDescriptor

impl UnwindSafe for ImageDelayloadDescriptor

impl<T> Any for ImageDelayloadDescriptor

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for ImageDelayloadDescriptor

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for ImageDelayloadDescriptor

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for ImageDelayloadDescriptor

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for ImageDelayloadDescriptor

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for ImageDelayloadDescriptor

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for ImageDelayloadDescriptor

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for ImageDelayloadDescriptor

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for ImageDelayloadDescriptor

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>