Struct ImageImportDescriptor

struct ImageImportDescriptor { ... }

Fields

original_first_thunk: U32Bytes<LittleEndian>

RVA to original unbound IAT (ImageThunkData32/ImageThunkData64) 0 for terminating null import descriptor

time_date_stamp: U32Bytes<LittleEndian>

0 if not bound, -1 if bound, and real date\time stamp in IMAGE_DIRECTORY_ENTRY_BOUND_IMPORT (new BIND) O.W. date/time stamp of DLL bound to (Old BIND)

forwarder_chain: U32Bytes<LittleEndian>

-1 if no forwarders

name: U32Bytes<LittleEndian>
first_thunk: U32Bytes<LittleEndian>

RVA to IAT (if bound this IAT has actual addresses)

Implementations

impl ImageImportDescriptor

fn is_null(self: &Self) -> bool

Tell whether this import descriptor is the null descriptor (used to mark the end of the iterator array in a PE)

impl Clone for ImageImportDescriptor

fn clone(self: &Self) -> ImageImportDescriptor

impl Copy for ImageImportDescriptor

impl Debug for ImageImportDescriptor

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for ImageImportDescriptor

impl Pod for ImageImportDescriptor

impl RefUnwindSafe for ImageImportDescriptor

impl Send for ImageImportDescriptor

impl Sync for ImageImportDescriptor

impl Unpin for ImageImportDescriptor

impl UnsafeUnpin for ImageImportDescriptor

impl UnwindSafe for ImageImportDescriptor

impl<T> Any for ImageImportDescriptor

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for ImageImportDescriptor

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for ImageImportDescriptor

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for ImageImportDescriptor

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for ImageImportDescriptor

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for ImageImportDescriptor

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for ImageImportDescriptor

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for ImageImportDescriptor

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for ImageImportDescriptor

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>