Struct ImageRelocation

struct ImageRelocation { ... }

Fields

virtual_address: U32Bytes<LittleEndian>

Also RelocCount when IMAGE_SCN_LNK_NRELOC_OVFL is set

symbol_table_index: U32Bytes<LittleEndian>
typ: U16Bytes<LittleEndian>

Implementations

impl ImageRelocation

fn symbol(self: &Self) -> SymbolIndex

Get the index of the symbol referenced by this relocation.

impl Clone for ImageRelocation

fn clone(self: &Self) -> ImageRelocation

impl Copy for ImageRelocation

impl Debug for ImageRelocation

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for ImageRelocation

impl Pod for ImageRelocation

impl RefUnwindSafe for ImageRelocation

impl Send for ImageRelocation

impl Sync for ImageRelocation

impl Unpin for ImageRelocation

impl UnsafeUnpin for ImageRelocation

impl UnwindSafe for ImageRelocation

impl<T> Any for ImageRelocation

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for ImageRelocation

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for ImageRelocation

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for ImageRelocation

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for ImageRelocation

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for ImageRelocation

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for ImageRelocation

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for ImageRelocation

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for ImageRelocation

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>