Struct ImageResourceDirectoryEntry

struct ImageResourceDirectoryEntry { ... }

Fields

name_or_id: U32<LittleEndian>
offset_to_data_or_directory: U32<LittleEndian>

Implementations

impl ImageResourceDirectoryEntry

fn has_name(self: &Self) -> bool

Returns true if the entry has a name, rather than an ID.

fn name_or_id(self: &Self) -> ResourceNameOrId

Returns the entry name

fn is_table(self: &Self) -> bool

Returns true if the entry is a subtable.

fn data_offset(self: &Self) -> u32

Returns the section offset of the associated table or data.

fn data<'data>(self: &Self, section: ResourceDirectory<'data>) -> Result<ResourceDirectoryEntryData<'data>>

Returns the data associated to this directory entry.

impl Clone for ImageResourceDirectoryEntry

fn clone(self: &Self) -> ImageResourceDirectoryEntry

impl Copy for ImageResourceDirectoryEntry

impl Debug for ImageResourceDirectoryEntry

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for ImageResourceDirectoryEntry

impl Pod for ImageResourceDirectoryEntry

impl RefUnwindSafe for ImageResourceDirectoryEntry

impl Send for ImageResourceDirectoryEntry

impl Sync for ImageResourceDirectoryEntry

impl Unpin for ImageResourceDirectoryEntry

impl UnsafeUnpin for ImageResourceDirectoryEntry

impl UnwindSafe for ImageResourceDirectoryEntry

impl<T> Any for ImageResourceDirectoryEntry

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for ImageResourceDirectoryEntry

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for ImageResourceDirectoryEntry

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for ImageResourceDirectoryEntry

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for ImageResourceDirectoryEntry

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for ImageResourceDirectoryEntry

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for ImageResourceDirectoryEntry

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for ImageResourceDirectoryEntry

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for ImageResourceDirectoryEntry

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>