FileKind

Enum FileKind 

#[non_exhaustive]
pub enum FileKind {
Show 16 variants Archive, Coff, CoffBig, CoffImport, DyldCache, Elf32, Elf64, MachO32, MachO64, MachOFat32, MachOFat64, Pe32, Pe64, Wasm, Xcoff32, Xcoff64,
}
A file format kind.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Archive

A Unix archive.

See archive::ArchiveFile.



Coff

A COFF object file.

See coff::CoffFile.



CoffBig

A COFF bigobj object file.

This supports a larger number of sections.

See coff::CoffBigFile.



CoffImport

A Windows short import file.

See coff::ImportFile.



DyldCache

A dyld cache file containing Mach-O images.

See macho::DyldCache



Elf32

A 32-bit ELF file.

See elf::ElfFile32.



Elf64

A 64-bit ELF file.

See elf::ElfFile64.



MachO32

A 32-bit Mach-O file.

See macho::MachOFile32.



MachO64

A 64-bit Mach-O file.

See macho::MachOFile64.



MachOFat32

A 32-bit Mach-O fat binary.

See macho::MachOFatFile32.



MachOFat64

A 64-bit Mach-O fat binary.

See macho::MachOFatFile64.



Pe32

A 32-bit PE file.

See pe::PeFile32.



Pe64

A 64-bit PE file.

See pe::PeFile64.



Wasm

A Wasm file.

See wasm::WasmFile.



Xcoff32

A 32-bit XCOFF file.

See xcoff::XcoffFile32.



Xcoff64

A 64-bit XCOFF file.

See xcoff::XcoffFile64.

Implementations

Source

impl FileKind

pub fn parse<'data, R: ReadRef<'data>>(data: R) -> Result<FileKind>

Determine a file kind by parsing the start of the file.

pub fn parse_at<'data, R: ReadRef<'data>>( data: R, offset: u64, ) -> Result<FileKind>

Determine a file kind by parsing at the given offset.