Nlist

Trait Nlist 

pub trait Nlist: Debug + Pod {
    type Word: Into<u64>;
    type Endian: Endian;

    // Required methods
    fn n_strx(&self, endian: Self::Endian) -> u32;
    fn n_type(&self) -> u8;
    fn n_sect(&self) -> u8;
    fn n_desc(&self, endian: Self::Endian) -> u16;
    fn n_value(&self, endian: Self::Endian) -> Self::Word;

    // Provided methods
    fn name<'data, R: ReadRef<'data>>(
        &self,
        endian: Self::Endian,
        strings: StringTable<'data, R>,
    ) -> Result<&'data [u8]> { ... }
    fn is_stab(&self) -> bool { ... }
    fn is_undefined(&self) -> bool { ... }
    fn is_definition(&self) -> bool { ... }
    fn library_ordinal(&self, endian: Self::Endian) -> u8 { ... }
}
A trait for generic access to macho::Nlist32 and macho::Nlist64.

Required Associated Types

Required Methods

fn n_strx(&self, endian: Self::Endian) -> u32

fn n_type(&self) -> u8

fn n_sect(&self) -> u8

fn n_desc(&self, endian: Self::Endian) -> u16

fn n_value(&self, endian: Self::Endian) -> Self::Word

Provided Methods

fn name<'data, R: ReadRef<'data>>( &self, endian: Self::Endian, strings: StringTable<'data, R>, ) -> Result<&'data [u8]>

fn is_stab(&self) -> bool

Return true if this is a STAB symbol.

This determines the meaning of the n_type field.

fn is_undefined(&self) -> bool

Return true if this is an undefined symbol.

fn is_definition(&self) -> bool

Return true if the symbol is a definition of a function or data object.

fn library_ordinal(&self, endian: Self::Endian) -> u8

Return the library ordinal.

This is either a 1-based index into the dylib load commands, or a special ordinal.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Endian: Endian> Nlist for Nlist32<Endian>

Source

type Word = u32

Source

type Endian = Endian

Source

impl<Endian: Endian> Nlist for Nlist64<Endian>

Source

type Word = u64

Source

type Endian = Endian