Permissions

Struct Permissions 

pub struct Permissions { /* private fields */ }
Memory permissions for a segment.

This is a simplified representation of segment permissions that abstracts over format-specific flags.

Implementations

Source

impl Permissions

pub fn new(readable: bool, writable: bool, executable: bool) -> Self

Creates a new Permissions with the given flags.

pub fn readable(&self) -> bool

Returns true if the segment is readable.

pub fn writable(&self) -> bool

Returns true if the segment is writable.

pub fn executable(&self) -> bool

Returns true if the segment is executable.

pub fn readonly(&self) -> bool

Returns true if the segment is readable but not writable.