Struct object::write::StreamingBuffer [−][src]
pub struct StreamingBuffer<W> { /* fields omitted */ }Expand description
A WritableBuffer that streams data to a Write implementation.
Self::result must be called to determine if an I/O error occurred during writing.
It is advisable to use a buffered writer like BufWriter
instead of an unbuffered writer like File.
Implementations
Unwraps this StreamingBuffer giving back the original writer.