Struct FunAux32
struct FunAux32 { ... }
Function auxiliary entry.
Fields
x_exptr: U32<BigEndian>File offset to exception table entry.
x_fsize: U32<BigEndian>Size of function in bytes.
x_lnnoptr: U32<BigEndian>File pointer to line number
x_endndx: U32<BigEndian>Symbol table index of next entry beyond this function.
pad: U16<BigEndian>Pad
Implementations
impl Clone for FunAux32
fn clone(self: &Self) -> FunAux32
impl Copy for FunAux32
impl Debug for FunAux32
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for FunAux32
impl Pod for FunAux32
impl RefUnwindSafe for FunAux32
impl Send for FunAux32
impl Sync for FunAux32
impl Unpin for FunAux32
impl UnsafeUnpin for FunAux32
impl UnwindSafe for FunAux32
impl<T> Any for FunAux32
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for FunAux32
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for FunAux32
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for FunAux32
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for FunAux32
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for FunAux32
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for FunAux32
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for FunAux32
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for FunAux32
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>