Struct FunAux64
struct FunAux64 { ... }
Function auxiliary entry.
Fields
x_lnnoptr: U64<BigEndian>File pointer to line number
x_fsize: U32<BigEndian>Size of function in bytes.
x_endndx: U32<BigEndian>Symbol table index of next entry beyond this function.
pad: u8Pad
x_auxtype: u8Contains _AUX_FCN; Type of auxiliary entry.
Implementations
impl Clone for FunAux64
fn clone(self: &Self) -> FunAux64
impl Copy for FunAux64
impl Debug for FunAux64
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for FunAux64
impl Pod for FunAux64
impl RefUnwindSafe for FunAux64
impl Send for FunAux64
impl Sync for FunAux64
impl Unpin for FunAux64
impl UnsafeUnpin for FunAux64
impl UnwindSafe for FunAux64
impl<T> Any for FunAux64
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for FunAux64
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for FunAux64
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for FunAux64
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for FunAux64
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for FunAux64
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for FunAux64
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for FunAux64
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for FunAux64
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>