Module endian

Module endian 

Types for compile-time and run-time endianness.

Structs

BigEndian
Compile-time big endian byte order.
I16
An unaligned i16 value with an externally specified endianness of type E.
I32
An unaligned i32 value with an externally specified endianness of type E.
I64
An unaligned i64 value with an externally specified endianness of type E.
LittleEndian
Compile-time little endian byte order.
U16
An unaligned u16 value with an externally specified endianness of type E.
U32
An unaligned u32 value with an externally specified endianness of type E.
U64
An unaligned u64 value with an externally specified endianness of type E.

Enums

Endianness
An endianness that is selectable at run-time.

Traits

Endian
A trait for using an endianness specification.
FixedEndian
An endianness specification that has a fixed value.

Type Aliases

I16BytesDeprecated
An unaligned i16 value with an externally specified endianness of type E.
I32BytesDeprecated
An unaligned i32 value with an externally specified endianness of type E.
I64BytesDeprecated
An unaligned i64 value with an externally specified endianness of type E.
NativeEndian
The native endianness for the target platform.
U16BytesDeprecated
An unaligned u16 value with an externally specified endianness of type E.
U32BytesDeprecated
An unaligned u32 value with an externally specified endianness of type E.
U64BytesDeprecated
An unaligned u64 value with an externally specified endianness of type E.