Module object::pod [−][src]
Tools for converting file format structures to and from bytes.
This module should be replaced once rust provides safe transmutes.
Structs
| Bytes | A newtype for byte slices. |
Traits
| Pod | A trait for types that can safely be converted from and to byte slices. |
| WritableBuffer | Trait for writable buffer. |
Functions
| bytes_of | Cast a |
| bytes_of_mut | Cast a |
| bytes_of_slice | Cast a slice of a |
| bytes_of_slice_mut | Cast a slice of a |
| from_bytes | Cast a byte slice to a |
| from_bytes_mut | Cast a mutable byte slice to a |
| slice_from_bytes | Cast a byte slice to a slice of a |
| slice_from_bytes_mut | Cast a mutable byte slice to a slice of a |