pub trait ObjectSymbolTable<'data>: Sealed {
type Symbol: ObjectSymbol<'data>;
type SymbolIterator: Iterator<Item = Self::Symbol>;
// Required methods
fn symbols(&self) -> Self::SymbolIterator;
fn symbol_by_index(&self, index: SymbolIndex) -> Result<Self::Symbol>;
}Expand description
A symbol table in an Object.
This trait is part of the unified read API.
Required Associated Types
Sourcetype Symbol: ObjectSymbol<'data>
type Symbol: ObjectSymbol<'data>
A symbol table entry.
Sourcetype SymbolIterator: Iterator<Item = Self::Symbol>
type SymbolIterator: Iterator<Item = Self::Symbol>
An iterator for the symbols in a symbol table.
Required Methods
Sourcefn symbols(&self) -> Self::SymbolIterator
fn symbols(&self) -> Self::SymbolIterator
Get an iterator for the symbols in the table.
This may skip over symbols that are malformed or unsupported.
Sourcefn symbol_by_index(&self, index: SymbolIndex) -> Result<Self::Symbol>
fn symbol_by_index(&self, index: SymbolIndex) -> Result<Self::Symbol>
Get the symbol at the given index.
The meaning of the index depends on the object file.
Returns an error if the index is invalid.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".