Struct ExpAux
struct ExpAux { ... }
Exception auxiliary entry. (XCOFF64 only)
Fields
x_exptr: U64<BigEndian>File offset to exception table entry.
x_fsize: U32<BigEndian>Size of function in bytes.
x_endndx: U32<BigEndian>Symbol table index of next entry beyond this function.
pad: u8Pad
x_auxtype: u8Contains _AUX_EXCEPT; Type of auxiliary entry
Implementations
impl Clone for ExpAux
fn clone(self: &Self) -> ExpAux
impl Copy for ExpAux
impl Debug for ExpAux
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for ExpAux
impl Pod for ExpAux
impl RefUnwindSafe for ExpAux
impl Send for ExpAux
impl Sync for ExpAux
impl Unpin for ExpAux
impl UnsafeUnpin for ExpAux
impl UnwindSafe for ExpAux
impl<T> Any for ExpAux
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ExpAux
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ExpAux
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for ExpAux
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for ExpAux
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for ExpAux
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for ExpAux
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ExpAux
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ExpAux
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>